@@ -127,7 +127,6 @@ gcAtomsDlg::gcAtomsDlg(gcDocument* pDoc): gcDialog(DATADIR"/gcrystal/glade/atoms
 	GtkTreeViewColumn *column;
 	/* column for element */
 	renderer = gtk_cell_renderer_text_new ();
-puts(_("Atom"));
 	column = gtk_tree_view_column_new_with_attributes(_("Atom"), renderer, "text", 0, NULL);
 	/* set this column to a minimum sizing (of 80 pixels) */
 	gtk_tree_view_column_set_sizing(GTK_TREE_VIEW_COLUMN (column), GTK_TREE_VIEW_COLUMN_GROW_ONLY);
@@ -191,8 +190,8 @@ puts(_("Atom"));
 	}
 	if (!m_Atoms->len)gtk_widget_set_sensitive(DeleteAllBtn, false);
 	AtomColor = (GnomeColorPicker*) glade_xml_get_widget(xml, "color");
-	gtk_widget_set_sensitive(GTK_WIDGET(AtomColor), false);
 	CustomColor = (GtkToggleButton*) glade_xml_get_widget(xml, "custom_color");
+	gtk_toggle_button_set_active(CustomColor, true);
 	g_signal_connect (G_OBJECT (CustomColor), "toggled", G_CALLBACK (on_toggled_color), this);
 	ChargeBtn = (GtkSpinButton*) glade_xml_get_widget(xml, "charge");
 	g_signal_connect (G_OBJECT (ChargeBtn), "value-changed", G_CALLBACK (on_charge_changed), this);
@@ -383,8 +382,15 @@ void gcAtomsDlg::OnElement(guint Z)
 			SetRadiusType(GCU_IONIC - 1);
 		}
 		PopulateRadiiMenu();
+		gtk_toggle_button_set_active(CustomColor, false);
+		double *Colors = Element::GetElement(m_nElt)->GetDefaultColor();
+		gnome_color_picker_set_d(AtomColor, Colors[0], Colors[1], Colors[2], 1.0);
+	}
+	else 
+	{
+		m_Radii = NULL;
+		gtk_toggle_button_set_active(CustomColor, true);
 	}
-	else m_Radii = NULL;
 	if (m_AtomSelected >= 0)
 	{
 		g_array_index(m_Atoms, struct AtomStruct, m_AtomSelected).Elt = Z;
